@@ -1,7 +1,7 @@
 package Test::Needs;
 use strict;
 use warnings;
-our $VERSION = '0.002001';
+our $VERSION = '0.002002';
 $VERSION =~ tr/_//d;
 
 BEGIN {
@@ -61,7 +61,7 @@ sub _find_missing {
               $version, (caller( 1 + ($Test::Builder::Level||0) ))[1,2];
         };
       if ("$]" < $version) {
-        "perl $version (have $])";
+        sprintf "perl %s (have %.6f)", $version, $];
       }
       else {
         ();
@@ -191,6 +191,7 @@ sub _fail_or_skip {
 
 my $terminate_event;
 sub _t2_terminate_event () {
+  local $@;
   $terminate_event ||= eval q{
     $INC{'Test/Needs/Event/Terminate.pm'} = $INC{'Test/Needs.pm'};
     package # hide
@@ -200,7 +201,7 @@ sub _t2_terminate_event () {
     sub no_display { 1 }
     sub terminate { 0 }
     __PACKAGE__;
-  } or die $@;
+  } or die "$@";
 }
 
 1;
